#!/bin/bash

if [ x$usearch == x ] ; then
	echo Must set \$usearch >> /dev/stderr
	exit 1
fi

out=../out

rm -rf $out
mkdir -p $out

cd $out

# Assign reads to samples (demultiplex) using barcode sequences.
$usearch -fastx_demux ../fq/reads.fq -barcodes ../scripts/barcodes.fa -fastqout demux.fq

# Delete barcode (14nt) and forward primer (CCGTCAATTCMTTTRAGT=18nt),
# total 32nt, then truncate to 350nt.
$usearch -fastx_truncate demux.fq -stripleft 32 -trunclen 350 -fastqout trunc.fq

# Discard low-quality reads
$usearch -fastq_filter trunc.fq -fastq_maxee 1.0 -relabel Filt -fastaout filtered.fa

# Find unique sequences and abundances
$usearch -fastx_uniques filtered.fa -sizeout -relabel Uniq -fastaout uniques.fa

# Make 97% OTUs
$usearch -cluster_otus uniques.fa -otus otus.fa -relabel Otu

# Make OTU table
$usearch -otutab trunc.fq -otus otus.fa -otutabout otutab.txt
